' *******************************************************************************************************
' *                                                                                                     *
' *     AiChip_Router_001.spin                                                                          *
' *                                                                                                     *
' *******************************************************************************************************

OBJ

  tv                            : "AiChip_TvText_001"
  serial                        : "AiChip_Serial_001"
  lcd                           : "AiChip_LCD_001"
  usb                           : "AiChip_USB_001"
  
CON

' .-----------------------------------------------------------------------------------------------------.
' |                                                                                                     |
' |     Device Routing                                                                                  |
' |                                                                                                     |
' `-----------------------------------------------------------------------------------------------------'
 
  ROUTE_NONE                    = 0
  ROUTE_TV                      = 1
  ROUTE_SERIAL                  = 2
  ROUTE_LCD                     = 3
  ROUTE_USB                     = 4

' .-----------------------------------------------------------------------------------------------------.
' |                                                                                                     |
' |     TV Modes                                                                                        |
' |                                                                                                     |
' `-----------------------------------------------------------------------------------------------------'
   
  TV_MODE_NTSC                  = tv#TV_MODE_NTSC
  TV_MODE_PAL                   = tv#TV_MODE_PAL

  TV_MODE_LARGE_FONT            = tv#TV_MODE_LARGE_FONT
  TV_MODE_SMALL_FONT            = tv#TV_MODE_SMALL_FONT

  TV_MODE_FAST_UPDATE           = tv#TV_MODE_FAST_UPDATE
  TV_MODE_FLICKER_FREE          = tv#TV_MODE_FLICKER_FREE

  TV_MODE_COLOR                 = tv#TV_MODE_COLOR
  TV_MODE_COLOUR                = tv#TV_MODE_COLOUR
  TV_MODE_MONOCHROME            = tv#TV_MODE_MONOCHROME
  
  TV_MODE_INTERLACED            = tv#TV_MODE_INTERLACED
  TV_MODE_NON_INTERLACED        = tv#TV_MODE_NON_INTERLACED

  TV_MODE_COMPOSITE             = tv#TV_MODE_COMPOSITE
  TV_MODE_BASEBAND              = tv#TV_MODE_BASEBAND
  TV_MODE_BROADCAST             = tv#TV_MODE_BROADCAST

  TV_MODE_FONT_0                = tv#TV_MODE_FONT_0
  TV_MODE_FONT_1                = tv#TV_MODE_FONT_1

  TV_MODE_RUNNING               = tv#TV_MODE_RUNNING
  
VAR

  byte deviceType

' *******************************************************************************************************
' *                                                                                                     *
' *     Device Handling Routines                                                                        *
' *                                                                                                     *
' *******************************************************************************************************

PUB Open( setDeviceType, setBasePin, setMode )

  deviceType := setDeviceType
  case deviceType
    ROUTE_TV                    : result := tv.Open( setBasePin, setMode )
    ROUTE_SERIAL                : result := serial.Open( setBasePin, setMode )
    ROUTE_LCD                   : result := lcd.Open( setBasePin, setMode )
    ROUTE_USB                   : result := usb.Open( setBasePin, setMode )

PUB Close( setDeviceType )

  case setDeviceType
    ROUTE_TV                    : result := tv.Close
    ROUTE_SERIAL                : result := serial.Close
    ROUTE_LCD                   : result := lcd.Close
    ROUTE_USB                   : result := usb.Close
    
' *******************************************************************************************************
' *                                                                                                     *
' *     Text Handling Routines                                                                          *
' *                                                                                                     *
' *******************************************************************************************************

PUB TxByte( b )

  case deviceType
    ROUTE_TV                    : tv.TxByte( b )
    ROUTE_SERIAL                : serial.TxByte( b )
    ROUTE_LCD                   : lcd.TxByte( b )
    ROUTE_USB                   : usb.TxByte( b )

PUB TxRawByte( b )

  case deviceType
    ROUTE_TV                    : tv.TxRawByte( b )
    ROUTE_SERIAL                : serial.TxRawByte( b )
    ROUTE_LCD                   : lcd.TxRawByte( b )
    ROUTE_USB                   : usb.TxRawByte( b )

PUB TxCrLf

  case deviceType
    ROUTE_TV                    : tv.TxCrLf
    ROUTE_SERIAL                : serial.TxCrLf
    ROUTE_LCD                   : lcd.TxCrLf
    ROUTE_USB                   : usb.TxCrLf
    
PUB Cls

  case deviceType
    ROUTE_TV                    : tv.Cls
    ROUTE_SERIAL                : serial.Cls
    ROUTE_LCD                   : lcd.Cls
    ROUTE_USB                   : usb.Cls
      
PUB Home

  case deviceType
    ROUTE_TV                    : tv.Home
    ROUTE_SERIAL                : serial.Home
    ROUTE_LCD                   : lcd.Home
    ROUTE_USB                   : usb.Home

PUB TxTab

  case deviceType
    ROUTE_TV                    : tv.TxTab
    ROUTE_SERIAL                : serial.TxTab
    ROUTE_LCD                   : lcd.TxTab
    ROUTE_USB                   : usb.TxTab

PUB TxBackSpace

  case deviceType
    ROUTE_TV                    : tv.TxBackSpace
    ROUTE_SERIAL                : serial.TxBackSpace
    ROUTE_LCD                   : lcd.TxBackSpace
    ROUTE_USB                   : usb.TxBackSpace

' *******************************************************************************************************
' *                                                                                                     *
' *     Logic Analyser Trace Handling Routines                                                          *
' *                                                                                                     *
' *******************************************************************************************************

PUB GetLogicAnalyserBit( thisBit, nextBit )

  case deviceType
    ROUTE_TV                    : result := tv.GetLogicAnalyserBit( thisBit, nextBit )
    ROUTE_SERIAL                : result := serial.GetLogicAnalyserBit( thisBit, nextBit )
    ROUTE_LCD                   : result := lcd.GetLogicAnalyserBit( thisBit, nextBit )
    ROUTE_USB                   : result := usb.GetLogicAnalyserBit( thisBit, nextBit )
  
' *******************************************************************************************************
' *                                                                                                     *
' *     Attribute Handling for Video Drivers                                                            *
' *                                                                                                     *
' *******************************************************************************************************

PUB GetColourCount

  case deviceType
    ROUTE_TV                    : result := tv.GetColourCount

PUB GetColumnCount

  case deviceType
    ROUTE_TV                    : result := tv.GetColumnCount
    ROUTE_LCD                   : result := lcd.GetColumnCount

PUB GetRowCount

  case deviceType
    ROUTE_TV                    : result := tv.GetRowCount
    ROUTE_LCD                   : result := lcd.GetRowCount
  
PUB GetCurrentColumn

  case deviceType
    ROUTE_TV                    : result := tv.GetCurrentColumn
    ROUTE_LCD                   : result := lcd.GetCurrentColumn
  
PUB GetCurrentRow

  case deviceType
    ROUTE_TV                    : result := tv.GetCurrentRow
    ROUTE_LCD                   : result := lcd.GetCurrentRow
    
' *******************************************************************************************************
' *                                                                                                     *
' *     Colour Palette Handling for Video Drivers                                                       *
' *                                                                                                     *
' *******************************************************************************************************

PUB SetPalette( ptrToPalette )

  case deviceType
    ROUTE_TV                    : tv.SetPalette( ptrToPalette )
               
PUB SetPaletteColour( colorIdx, fore, back )

  case deviceType
    ROUTE_TV                    : tv.SetPaletteColour( colorIdx, fore, back )

PUB SetColour( useColour )

  case deviceType
    ROUTE_TV                    : tv.SetColour( useColour )

' *******************************************************************************************************
' *                                                                                                     *
' *     End of AiChip_Router_001.spin                                                                   *
' *                                                                                                     *
' *******************************************************************************************************